<?php
/**
 * Custom template tags for Weeland
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @since Weeland 1.0
 */

if ( ! function_exists( 'weeland_site_identity' ) ) :
  /**
   * Prints HTML with blog title and description.
   *
   * @since Weeland 1.0
   */
  function weeland_site_identity() {
    the_custom_logo();

    if( get_theme_mod( 'display_site_title', 1 ) ) {
      printf( '<%1$s class="site-title"><a href="%2$s" rel="home">%3$s</a></%1$s>', 
        is_front_page() && is_home() ? 'h1' : 'p', 
        esc_url( home_url( '/' ) ), 
        esc_html( get_bloginfo( 'name' ) ) 
      );
    }

    weeland_tagline( '<div class="tagline">', '</div>' );
  }
endif;

if ( ! function_exists( 'weeland_tagline' ) ) :
  /**
   * Prints HTML with custom header text.
   *
   * @since Weeland 1.0
   */
  function weeland_tagline( $before = '', $after = '' ) {
    $header_text = get_transient( 'weeland_tagline' );
    
    if( $header_text === false || is_customize_preview() ) {
      $header_text = get_theme_mod( 'tagline' );
      
      if( $header_text ) {
        $header_text = wp_kses( $header_text, array(
            'a' => array(
              'href' => array(),
              'title' => array()
            ),
            'p'      => array(),
            'b'      => array(),
            'strong' => array(),
            'em'     => array(),
            'i'      => array(),
            'br'     => array(),
            'span'   => array(),
            'img' => array(
              'src' => array(),
              'alt' => array(),
              'title' => array()
            )
          )
        );
      }
      set_transient( 'weeland_tagline', $header_text );
    }
    
    if( $header_text || is_customize_preview() )
      printf( '%s%s%s', $before, $header_text, $after );
  }
endif;

if ( ! function_exists( 'weeland_site_copyright' ) ) :
  /**
   * Prints HTML with custom or default copyright text.
   *
   * @since Weeland 1.0
   */
  function weeland_site_copyright( $before = '', $after = '' ) {
    $default_copyright = sprintf( '&copy; %1$d <a href="%2$s">%3$s</a>', date('Y'), esc_url( home_url( '/' ) ), esc_html( get_bloginfo( 'name' ) ) );
    
    $copyright = get_transient( 'weeland_copyright' );
    
    if( $copyright === false || is_customize_preview() ) {
      $copyright = get_theme_mod( 'copyright' );
      
      if( $copyright ) {
        $copyright = wp_kses( $copyright, array(
            'a' => array(
              'href' => array(),
              'title' => array()
            ),
            'p'      => array(),
            'b'      => array(),
            'strong' => array(),
            'em'     => array(),
            'i'      => array(),
            'br'     => array(),
            'span'   => array(),
            'img' => array(
              'src' => array(),
              'alt' => array(),
              'title' => array()
            )
          )
        );
      }
      set_transient( 'weeland_copyright', $copyright );
    }
    
    printf( '%s%s%s', $before, $copyright ? $copyright : $default_copyright, $after );
  }
endif;

if ( ! function_exists( 'weeland_post_thumbnail' ) ) :
  /**
   * Display an optional post thumbnail.
   *
   * Wraps the post thumbnail in an anchor element on index views, or a div
   * element when on single views.
   *
   * @since Weeland 1.0
   */
  function weeland_post_thumbnail( $size = 'post-thumbnail' ) {
    if ( post_password_required() || is_attachment() || ! has_post_thumbnail()  ) {
      return;
    }

    if ( is_singular() ) :
    ?>

    <div class="post-thumbnail">
      <?php the_post_thumbnail( $size ); ?>
    </div><!-- .post-thumbnail -->

    <?php else : ?>

    <a class="post-thumbnail" href="<?php the_permalink(); ?>" aria-hidden="true">
      <?php the_post_thumbnail( $size, array( 'alt' => get_the_title() ) ); ?>
    </a>

    <?php endif; // End is_singular()
  }
endif;

if ( ! function_exists( 'weeland_entry_meta' ) ) :
  /**
   * Prints HTML with meta information for the categories, post date.
   *
   * @since Weeland 1.0
   */
  function weeland_entry_meta( $before = '', $after = '', $display_date = true, $display_author = true ) {
    $output = '';
    $post_type = get_post_type();

    if ( in_array( $post_type, array( 'post', 'attachment' ) ) && $display_date ) {
      $time_string = sprintf( '<time class="entry-date published" datetime="%1$s">%2$s</time>',
        esc_attr( get_the_date( 'c' ) ),
        get_the_date()
      );

      $output .= sprintf( '<span class="posted-on post-meta">%s</span>', sprintf( esc_html__( 'Posted on %s', 'weeland' ), $time_string ) );
    }

    if ( 'post' == $post_type && $display_author ) {
      $author_string = sprintf( '<a class="url fn" href="%s">%s</a>', esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ), get_the_author() );
      $author_string = sprintf( esc_html_x( 'by %s', 'Post author', 'weeland' ), $author_string );
    
      $output .= sprintf( '<span class="byline author vcard post-meta">%s</span>', $author_string );
    }

    if( $output )
      printf( '%s%s%s', $before, $output, $after );
  }
endif;

if ( ! function_exists( 'weeland_category_list' ) ) :
  /**
   * Prints HTML with post categories list.
   *
   * @since Weeland 1.0
   */
  function weeland_category_list() {
    global $post;

    if( ! $post )
      return;

    $post_type = $post->post_type;
    
    if ( 'post' == $post_type ) {
      $categories_list = get_the_category_list( ' ' );

      if( $categories_list ) {
        printf( '<div class="cat-links">%s</div>', $categories_list );
      } 
    }

    return;
  }
endif;

if ( ! function_exists( 'weeland_entry_footer' ) ) :
  /**
   * Prints HTML with post tags and share buttons in post footer
   *
   * @since Weeland 1.0
   */
  function weeland_entry_footer( $display_tags = true, $display_share_buttons = true, $before = '', $after = '' ) {
    $output = '';
    $post = get_post();
    
    if ( is_singular( 'post' ) && $display_tags ) {
        $output .= get_the_tag_list( '<div class="tags-list">', '', '</div>' );
    }

    if( is_singular() && $display_share_buttons && function_exists( 'wsbn_get_share_buttons' ) ) {
      $output .= sprintf( '<div class="entry-share">%s</div>', wsbn_get_share_buttons() );
    }
    
    if( $output )
      printf( '%s%s%s', $before, $output, $after );
  }
endif;

if ( ! function_exists( 'weeland_display_page_title' ) ) :
  /**
   * Checking if the page title is displayed or not.
   *
   * @since Weeland 1.0
   */
  function weeland_display_page_title() {
    global $post;

    if( !$post )
      return false;

    $page_options = get_post_meta( $post->ID, 'weeland_page_options', true );
    $display_page_title = isset( $page_options['display_title'] ) ? $page_options['display_title'] : true;

    return (bool) $display_page_title;
  }
endif;

if ( ! function_exists( 'weeland_related_posts' ) ) :
  /**
   * Related posts for current post.
   *
   * @since Weeland 1.0
   */
  function weeland_related_posts( $before = '', $after = '' ) {
    global $post;
    
    if( !$post )
      return;

    if( $post->post_type !== 'post' )
      return;
      
    $query_args = array(
      'post__not_in'        => array( $post->ID ),
      'posts_per_page'      => 3,
      'ignore_sticky_posts' => true
    );
    
    $related_by = get_theme_mod( 'related_by', 'none' );
    
    switch ( $related_by ) {
      case 'category' :
        $categories = get_the_category( $post->ID );
        if ( $categories ) {
          $category_ids = array();
          foreach( $categories as $category ) 
            $category_ids[] = $category->term_id;
            
          $query_args['category__in'] = $category_ids;
        }
        break;
      
      case 'tags' :
        $tags = wp_get_post_tags( $post->ID );
        if ( $tags ) {
          $tag_ids = array();
          foreach( $tags as $tag ) 
            $tag_ids[] = $tag->term_id;
            
          $query_args['tag__in'] = $tag_ids;
        }
        break;
      case 'none' :
        $query_args['orderby'] = 'rand';
        break;
    }
    
    $related_posts = new WP_Query( $query_args );
    $output = '';
    
    if( $related_posts->have_posts() ) {
      printf( '%s<div class="related-posts">', $before );
      
      while( $related_posts->have_posts() ) : $related_posts->the_post(); ?>
      <div class="related-post<?php if( has_post_thumbnail() ) : ?> has-post-thumbnail<?php endif; ?>">
      
        <?php if( has_post_thumbnail() ) : ?>
        <a href="<?php the_permalink()?>" class="post-thumbnail" rel="bookmark" title="<?php the_title(); ?>">
          <?php the_post_thumbnail( 'weeland-medium-thumbnail' ); ?>
        </a>
        <?php endif; ?>
        
        <div class="related-post-content">
          <a href="<?php the_permalink(); ?>" rel="bookmark" title="<?php the_title(); ?>"><?php the_title(); ?></a>
          <?php printf( '<div class="post-meta">%s</div>', get_the_date() ); ?>
        </div>
      </div>
    <?php 
      endwhile;
      
      printf( '</div>%s', $after );
    }

    wp_reset_postdata(); 
  }
endif;

/**
 * Displays SVG icons in social links menu.
 *
 * @param string   $item_output The menu item's starting HTML output.
 * @param WP_Post  $item        Menu item data object.
 * @param int      $depth       Depth of the menu. Used for padding.
 * @param stdClass $args        An object of wp_nav_menu() arguments.
 * @return string The menu item output with social icon.
 */
function weeland_nav_menu_social_icons( $item_output, $item, $depth, $args ) {
  // Change SVG icon inside social links menu if there is supported URL.
  if ( $args->theme_location === 'social'  ) {
      $svg = Weeland_SVG_Icons::get_social_link_svg( $item->url );
      if ( empty( $svg ) ) {
          $svg = weeland_get_theme_svg( 'link' );
      }
      $item_output = str_replace( $args->link_after, '</span>' . $svg, $item_output );
  }

  return $item_output;
}

add_filter( 'walker_nav_menu_start_el', 'weeland_nav_menu_social_icons', 10, 4 );

/**
 * Filters classes of wp_list_pages items to match menu items.
 *
 * Filter the class applied to wp_list_pages() items with children to match the menu class, to simplify.
 * styling of sub levels in the fallback. Only applied if the match_menu_classes argument is set.
 *
 * @param string[] $css_class    An array of CSS classes to be applied to each list item.
 * @param WP_Post  $page         Page data object.
 * @param int      $depth        Depth of page, used for padding.
 * @param array    $args         An array of arguments.
 * @param int      $current_page ID of the current page.
 * @return array CSS class names.
 */
function weeland_filter_wp_list_pages_item_classes( $css_class, $page, $depth, $args, $current_page ) {

  // Only apply to wp_list_pages() calls with match_menu_classes set to true.
  $match_menu_classes = isset( $args['match_menu_classes'] );

  if ( ! $match_menu_classes ) {
    return $css_class;
  }

  // Add current menu item class.
  if ( in_array( 'current_page_item', $css_class, true ) ) {
    $css_class[] = 'current-menu-item';
  }

  // Add menu item has children class.
  if ( in_array( 'page_item_has_children', $css_class, true ) ) {
    $css_class[] = 'menu-item-has-children';
  }

  return $css_class;

}

add_filter( 'page_css_class', 'weeland_filter_wp_list_pages_item_classes', 10, 5 );

/**
 * Adds a Sub Nav Icons to navigation menus.
 *
 * @param stdClass $args  An object of wp_nav_menu() arguments.
 * @param WP_Post  $item  Menu item data object.
 * @param int      $depth Depth of menu item. Used for padding.
 * @return stdClass An object of wp_nav_menu() arguments.
 */
function weeland_add_sub_toggles_to_main_menu( $args, $item, $depth ) {

  // Add sub menu toggles to the Expanded Menu with toggles.
  if ( isset( $args->show_sub_menu_icons ) && $args->show_sub_menu_icons ) {

    // Wrap the menu item link contents in a div, used for positioning.
    $args->before = '<div class="ancestor-wrapper">';
    $args->after  = '';

    // Add a toggle to items with children.
    if ( in_array( 'menu-item-has-children', $item->classes, true ) ) {

      // Add the sub menu toggle.
      $args->after .= '<span class="submenu-arrow">' . weeland_get_theme_svg( 'chevron-down' ) . '</span>';

    }

    // Close the wrapper.
    $args->after .= '</div><!-- .ancestor-wrapper -->';
  }

  return $args;

}

add_filter( 'nav_menu_item_args', 'weeland_add_sub_toggles_to_main_menu', 10, 3 );
?>